==> icons-vue-0.6.0.tgz: package/es/keyboard/16.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../_rollupPluginBabelHelpers-8169a350.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_Keyboard16 = {
  name: 'Keyboard16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M28,26H4a2,2,0,0,1-2-2V10A2,2,0,0,1,4,8H28a2,2,0,0,1,2,2V24A2,2,0,0,1,28,26ZM4,10V24H28V10Z"
      }
    }), createElement('rect', {
      attrs: {
        "width": "11",
        "height": "2",
        "x": "10",
        "y": "20"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "6",
        "y": "12"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "10",
        "y": "12"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "14",
        "y": "12"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "18",
        "y": "12"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "6",
        "y": "20"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "6",
        "y": "16"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "10",
        "y": "16"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "14",
        "y": "16"
      }
    }), createElement('rect', {
      attrs: {
        "width": "4",
        "height": "2",
        "x": "22",
        "y": "12"
      }
    }), createElement('rect', {
      attrs: {
        "width": "4",
        "height": "2",
        "x": "22",
        "y": "16"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "18",
        "y": "16"
      }
    }), createElement('rect', {
      attrs: {
        "width": "3",
        "height": "2",
        "x": "23",
        "y": "20"
      }
    }), children]);
  }
};

export default virtual_Keyboard16;

==> icons-vue-10.6.1.tgz: package/es/keyboard/16.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../chunk-75bb93d0.js';
import { getAttributes } from '@carbon/icon-helpers';

var virtual_Keyboard16 = {
  name: 'Keyboard16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M28 26H4a2 2 0 0 1-2-2V10a2 2 0 0 1 2-2h24a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2zM4 10v14h24V10z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M10 20h11v2H10zm-4-8h2v2H6zm4 0h2v2h-2zm4 0h2v2h-2zm4 0h2v2h-2zM6 20h2v2H6zm0-4h2v2H6zm4 0h2v2h-2zm4 0h2v2h-2zm8-4h4v2h-4zm0 4h4v2h-4zm-4 0h2v2h-2zm5 4h3v2h-3z"
      }
    }), children]);
  }
};

export default virtual_Keyboard16;
